Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(613)

Unified Diff: chrome/browser/chromeos/language_preferences.cc

Issue 11741003: Remove PrefServiceSimple, replacing it with PrefService and PrefRegistrySimple. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix double registration in Chrome Frame test. Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/language_preferences.cc
diff --git a/chrome/browser/chromeos/language_preferences.cc b/chrome/browser/chromeos/language_preferences.cc
index 77658dd6b658925295859436fec4b7626779dd33..77e95184430cf2440eb982fe69b9d7d03d29d321 100644
--- a/chrome/browser/chromeos/language_preferences.cc
+++ b/chrome/browser/chromeos/language_preferences.cc
@@ -4,6 +4,7 @@
#include "base/basictypes.h"
#include "chrome/browser/chromeos/language_preferences.h"
+#include "chrome/browser/prefs/pref_registry_simple.h"
#include "chrome/common/pref_names.h"
#include "grit/generated_resources.h"
@@ -392,13 +393,12 @@ const int kXkbAutoRepeatDelayInMs = 500;
const int kXkbAutoRepeatIntervalInMs = 50;
const char kPreferredKeyboardLayout[] = "PreferredKeyboardLayout";
-void RegisterPrefs(PrefServiceSimple* local_state) {
+void RegisterPrefs(PrefRegistrySimple* registry) {
// We use an empty string here rather than a hardware keyboard layout name
// since input_method::GetHardwareInputMethodId() might return a fallback
// layout name if local_state->RegisterStringPref(kHardwareKeyboardLayout)
// is not called yet.
- local_state->RegisterStringPref(kPreferredKeyboardLayout,
- "");
+ registry->RegisterStringPref(kPreferredKeyboardLayout, "");
}
} // namespace language_prefs
« no previous file with comments | « chrome/browser/chromeos/language_preferences.h ('k') | chrome/browser/chromeos/login/login_utils_browsertest.cc » ('j') | no next file with comments »
@@ -392,13 +393,12 @@ const int kXkbAutoRepeatDelayInMs = 500;
// We use an empty string here rather than a hardware keyboard layout name
// since input_method::GetHardwareInputMethodId() might return a fallback
- // layout name if local_state->RegisterStringPref(kHardwareKeyboardLayout)
+ // layout name if registry->RegisterStringPref(kHardwareKeyboardLayout)
// is not called yet.

Powered by Google App Engine
This is Rietveld 408576698